#!/usr/bin/perl
#
# $Id: consolidate.pl,v 1.4 1998/05/07 18:45:21 wralph Exp $
#
#  Script to uncompress the hourly tcpdump data files, put them all
#  back into one giant file and then create separate files for the
#  major protocols.
#  
#  Written by Bill Ralph 3/17/98
#
# Set up some variables.
#
use Getopt::Long;
use POSIX qw(strftime);
#
$ENV{PATH} = "/bin:/usr/bin:/usr/sbin:/usr/local/bin:/usr/local/logger";
$clean_time=time-3*24*60*60-15*60;
$SITE="Site1";
$FILTER_DIR="/usr/local/logger/filters";
$SENSOR_DIR="/LOG/$SITE";
$subdir=strftime("%h%d", localtime($clean_time));
#
sub usage {
        print "Usage: consolidate.pl -debug -d SNIFDATE -l SITE.\n";
	exit 2;
}
#
#	Parse the parameters.
#
#
&GetOptions("debug", \$debug, "d:s", \$snifdate, "l:s", \$SITE);
##
#
#  Check parameter validity.
#
if ("$SITE" eq "")
{
	usage();
}
#
if ($debug)
{
   print "d = $snifdate \n";
   print "l = $SITE \n";
}
#
#  Rid ourselves of standard output and error to prevent tons of mail messages
#  from cron.
#
if ( $debug )
{
   open(STDOUT, ">>/tmp/consolidate.log");
   select STDOUT; $| = 1;              # make unbuffered
} else {
   open(STDOUT, ">>/dev/null");
   select STDOUT; $| = 1;
}
open(STDERR, ">&STDOUT");
select STDERR; $| = 1;              # make unbuffered
#
# Writer a marker to the log file.
#
$marker=strftime("%c", localtime(time));
print STDOUT $marker;
foreach $param ($0, @ARGV) {
   printf " %s", $param;
}
print STDOUT "\n";
#
# If we have been called with a SNIFDATE parameter, reset the $subdir variable.
#
if ($snifdate ne "") {
   $year=substr($snifdate,0,2);
   $mon=substr($snifdate,2,2) - 1;
   $mday=substr($snifdate,4,2);
   $subdir=strftime("%h%d", 0, 0, 0, $mday, $mon, $year, 0, 0, 0);
   if ($debug)
   {
      print STDOUT "subdir = $subdir\n";
   }
}
#
# Ready to start the work now, find the hourly data files.
#
print STDOUT ("${SENSOR_DIR}/${subdir}\n");
#
# unzip the hourly data files.
#
#
#
chdir("${SENSOR_DIR}/${subdir}");
@files=<tcp.*.gz>;
if ($files[0] eq "") {
   print STDOUT ("No zipped hourly files found, moving on.\n");
} else {
   foreach $file (@files) {
      if ($debug) {
         print STDOUT ("Unzipping $file\n");
      }
      system("gunzip -f $file") == 0 or unlink($file);
   }
}
#
#  Build an entire day file from the hourly pieces.
#
if (! -e "day_whole") {
   print STDOUT ("tcpslice tcp.* > day_whole\n");
   system("tcpslice tcp.* > day_whole") == 0 or die "tcpslice failed: $?";
}
#
#  Remove the hourly pieces
#
@files=<tcp.*>;
if ($files[0] ne "") {
   foreach $file (@files) {
#     print STDOUT ("Removing $file\n");
      unlink($file) or die "Unable to remove $file:$?";
   }
} else {
   print STDOUT ("No unzipped hourly files found.\n");
}
#
#  Separate the whole day into tcp, udp, icmp, and everything_else pieces.
#  Combine the tcpdumping with the gzipping at the suggestion of Andy Kutner
#  (akutner@lbl.gov).
#
if (! -e "day_tcp") {
   $tcpdump_cmd="tcpdump -r day_whole -w - -F $FILTER_DIR/tcp-connections";
   $gzip_cmd="gzip -f -c > day_tcp.gz";
   system("$tcpdump_cmd | $gzip_cmd") == 0 or 
        die "tcpdump/gzip failed on tcp-connections: $?";
   print STDOUT ("$tcpdump_cmd | $gzip_cmd\n");
}
if (! -e "day_udp") {
   $tcpdump_cmd="tcpdump -r day_whole -w - -F $FILTER_DIR/udp";
   $gzip_cmd="gzip -f -c > day_udp.gz";
   system("$tcpdump_cmd | $gzip_cmd") == 0 or 
        die "tcpdump/gzip failed on tcp-connections: $?";
   print STDOUT ("$tcpdump_cmd | $gzip_cmd\n");
}
if (! -e "day_icmp") {
   $tcpdump_cmd="tcpdump -r day_whole -w - -F $FILTER_DIR/icmp";
   $gzip_cmd="gzip -f -c > day_icmp.gz";
   system("$tcpdump_cmd | $gzip_cmd") == 0 or 
        die "tcpdump/gzip failed on tcp-connections: $?";
   print STDOUT ("$tcpdump_cmd | $gzip_cmd\n");
}
if (! -e "day_else") {
   $tcpdump_cmd="tcpdump -r day_whole -w - -F $FILTER_DIR/everything-else";
   $gzip_cmd="gzip -f -c > day_else.gz";
   system("$tcpdump_cmd | $gzip_cmd") == 0 or 
        die "tcpdump/gzip failed on tcp-connections: $?";
   print STDOUT ("$tcpdump_cmd | $gzip_cmd\n");
}
#
#  Now remove the whole day file.
#
unlink(day_whole) or print STDOUT "unlink failed on day_whole.\n";
