#!/usr/bin/perl
#
# $Id: convert.pl,v 1.2 1998/04/28 19:15:15 wralph Exp $
#
#  Script to convert a plain text file created by an older fetchem
#  to an html file for pretty web viewing.
#  
#  Written by Bill Ralph 3/31/98
#
# Set up some variables.
#
use Getopt::Long;
use POSIX qw(strftime);
use Time::Local;
#
$ENV{PATH} = "/bin:/usr/bin:/usr/sbin:/usr/local/bin:/usr/local/logger";
$SITE="Site1";
$SENSOR="sensor01";
$OUTPUT_DIR="/home/httpd/html/tcpdump_results/$SITE";
$URL_OUTPUT_DIR="/tcpdump_results/$SITE";
$FILTER_DIR="/usr/local/logger/filters";
#
sub usage {
        print "Usage: convert -debug -d SNIFDATE -l LOGGER_LOCATION -n LOGGER_NAME.\n";
	exit 2;
}
#
#	Parse the parameters.
#
#
&GetOptions("debug", \$debug, "d=s", \$snifdate, "l:s", \$SITE, "n:s", \$SENSOR);
##
#
#  Rid ourselves of standard output and error to prevent tons of mail messages
#  from cron.
#
if ( not $debug )
{
   open(STDOUT, ">>/tmp/convert.log");
   open(STDERR, ">&STDOUT");
   select STDERR; $| = 1;              # make unbuffered
   select STDOUT; $| = 1;              # make unbuffered
}
#
# Writer a marker to the log file.
#
$marker=strftime("%c", localtime(time));
print STDOUT $marker;
foreach $param ($0, @ARGV) {
   printf " %s", $param;
}
print STDOUT "\n";
#
#  Check parameter validity.
#
if ("$SITE" eq "" or "$SENSOR" eq "")
{
	usage();
}
#
#
#  Add the logger_location component to the web page path.
#
$OUTPUT_DIR="/home/httpd/html/tcpdump_results/$SITE";
$URL_OUTPUT_DIR="/tcpdump_results/$SITE";
#
#  Break up the "snifdate" into its useful components.
#
$year=substr($snifdate,0,2);
$mon=substr($snifdate,2,2) - 1;
$mday=substr($snifdate,4,2);
print STDOUT "$year, $mon, $mday\n";
$dir=strftime("%h%d", 0, 0, 0, $mday, $mon, $year, 0, 0, 0);
print STDOUT "DIR: $dir\n";
#
# Convert our snif date back to seconds from 1/1/1970.
#
$snif_time = timelocal(0, 0, 0, $mday, $mon, $year);
print STDOUT "Snif Time = $snif_time\n";
$yester_dir = strftime("%h%d", localtime($snif_time - 86400));
print STDOUT "yester_dir = $yester_dir\n";
$tomorrow_dir = strftime("%h%d", localtime($snif_time + 86400));
print STDOUT "tomorrow_dir = $tomorrow_dir\n";
if ($debug) {
   print STDOUT "snifdate = $snifdate, dir = $dir\n";
}
#
#  Loop over each 24 hours in an approximate day.
#
for ($counter=0; $counter <24; $counter++) {
   if ($counter <10) {
      $hour_only="0".$counter;
   } else {
      $hour_only=$counter;
   }
   $hour=$hour_only. ":00";
   $newdate = $snifdate . " " . $hour;
   $newtime = $snif_time + 3600*$counter;
   $currentdate=$snifdate . $hour_only;
   if ($debug) {
      print STDOUT "hour = $hour, hour_only = $hour_only\n";
      print STDOUT "newdate = $newdate\n";
   }
#
# Predict the previous hour and next hour for html links.
#
   $last_hour = strftime("%y%m%d%H", localtime($newtime - 3600));
   $last_hour_dir = strftime("%h%d", localtime($newtime - 3600));
   $next_hour  = strftime("%y%m%d%H", localtime($newtime + 3600));
   $next_hour_dir = strftime("%h%d", localtime($newtime + 3600));
   if ($debug) {
      print STDOUT "Last HR. = $last_hour, Next HR. = $next_hour\n";
      print STDOUT "Last HR/dir = $last_hour_dir, Next HR/dir = $next_hour_dir\n";
   }
#
#  Make sure subdirectory "MONXX" exists under on web page
#
   if (not -d "/$OUTPUT_DIR/$dir") {
       die "Unable to mkdir /$OUTPUT_DIR/$dir";
   } else {
#
#  Create the index for the day represented by the directory we just 
#  created. The index.html files will be a page listing one html file for
#  each hour of the day - prettified a tiny bit.
#
      chdir("/$OUTPUT_DIR/$dir");
      open(DAYINDEX, ">index.html");
   print DAYINDEX <<"EOF";
<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.0 Final//EN">
<HTML>
<HEAD><TITLE>Daily TCPDUMP Files for $dir
</TITLE>
</HEAD>
<BODY CLEAR=BOTH BACKGROUND="/images/legalpad.GIF">
<H2>Hourly TCPDUMP results for $dir</H$>
<UL TYPE=DISC> 
<FONT SIZE=+1>
<LI><A HREF="$URL_OUTPUT_DIR/$dir/${snifdate}00.html">Midnight till 1 AM</A></LI> 
<LI><A HREF="$URL_OUTPUT_DIR/$dir/${snifdate}01.html">Between 1 and 2 AM</A></LI> 
<LI><A HREF="$URL_OUTPUT_DIR/$dir/${snifdate}02.html">Between 2 and 3 AM</A></LI> 
<LI><A HREF="$URL_OUTPUT_DIR/$dir/${snifdate}03.html">Between 3 and 4 AM</A></LI> 
<LI><A HREF="$URL_OUTPUT_DIR/$dir/${snifdate}04.html">Between 4 and 5 AM</A></LI> 
<LI><A HREF="$URL_OUTPUT_DIR/$dir/${snifdate}05.html">Between 5 and 6 AM</A></LI> 
<LI><A HREF="$URL_OUTPUT_DIR/$dir/${snifdate}06.html">Between 6 and 7 AM</A></LI> 
<LI><A HREF="$URL_OUTPUT_DIR/$dir/${snifdate}07.html">Between 7 and 8 AM</A></LI> 
<LI><A HREF="$URL_OUTPUT_DIR/$dir/${snifdate}08.html">Between 8 and 9 AM</A></LI> 
<LI><A HREF="$URL_OUTPUT_DIR/$dir/${snifdate}09.html">Between 9 and 10 AM</A></LI> 
<LI><A HREF="$URL_OUTPUT_DIR/$dir/${snifdate}10.html">Between 10 and 11 AM</A></LI> 
<LI><A HREF="$URL_OUTPUT_DIR/$dir/${snifdate}11.html">Between 11 AM and Noon</A></LI> 
<LI><A HREF="$URL_OUTPUT_DIR/$dir/${snifdate}12.html">Lunch</A></LI> 
<LI><A HREF="$URL_OUTPUT_DIR/$dir/${snifdate}13.html">Between 1 and 2 PM</A></LI> 
<LI><A HREF="$URL_OUTPUT_DIR/$dir/${snifdate}14.html">Between 2 and 3 PM</A></LI> 
<LI><A HREF="$URL_OUTPUT_DIR/$dir/${snifdate}15.html">Between 3 and 4 PM</A></LI> 
<LI><A HREF="$URL_OUTPUT_DIR/$dir/${snifdate}16.html">Between 4 and 5 PM</A></LI> 
<LI><A HREF="$URL_OUTPUT_DIR/$dir/${snifdate}17.html">Between 5 and 6 PM</A></LI> 
<LI><A HREF="$URL_OUTPUT_DIR/$dir/${snifdate}18.html">Between 6 and 7 PM</A></LI> 
<LI><A HREF="$URL_OUTPUT_DIR/$dir/${snifdate}19.html">Between 7 and 8 PM</A></LI> 
<LI><A HREF="$URL_OUTPUT_DIR/$dir/${snifdate}20.html">Between 8 and 9 PM</A></LI> 
<LI><A HREF="$URL_OUTPUT_DIR/$dir/${snifdate}21.html">Between 9 and 10 PM</A></LI> 
<LI><A HREF="$URL_OUTPUT_DIR/$dir/${snifdate}22.html">Between 10 and 11 PM</A></LI> 
<LI><A HREF="$URL_OUTPUT_DIR/$dir/${snifdate}23.html">Between 11 PM and Midnight</A></LI> 
</FONT>
</UL>

<TABLE CELLSPACING="0" CELLPADDING="0">
<TR>
<TD ALIGN=CENTER VALIGN=MIDDLE><A HREF="$URL_OUTPUT_DIR/$yester_dir/index.html"><IMG SRC="/images/navbars/2/1.gif" WIDTH="90" HEIGHT="20" BORDER="0" HSPACE="0" VSPACE="0"></A><IMG SRC="/images/navbars/2/2.gif" WIDTH="110" HEIGHT="20" HSPACE="0" VSPACE="0"><A HREF="/tcpdump_results/index.html"><IMG SRC="/images/navbars/2/3.gif" WIDTH="50" HEIGHT="20" BORDER="0" HSPACE="0" VSPACE="0"></A><IMG SRC="/images/navbars/2/2.gif" WIDTH="110" HEIGHT="20" HSPACE="0" VSPACE="0"><A HREF="$URL_OUTPUT_DIR/$tomorrow_dir/index.html"><IMG SRC="/images/navbars/2/5.gif" WIDTH="90" HEIGHT="20" BORDER="0" HSPACE="0" VSPACE="0"></A></TD></TR>
</TABLE>
</BODY>
</HTML>
EOF
      close(DAYINDEX);
   }
#
#  Check to insure that the text file is in the web page, else re-create it.
#
   $zipped_file="/LOG/".$SITE."/".$dir."/tcp.".$currentdate.".gz";
   $output_txt_file="$OUTPUT_DIR/$dir/$currentdate.txt";
   $output_html_file="$OUTPUT_DIR/$dir/$currentdate.html";
   $prev_out_file="$URL_OUTPUT_DIR/$last_hour_dir/$last_hour.html";
   $next_out_file="$URL_OUTPUT_DIR/$next_hour_dir/$next_hour.html";
   if ($debug) {
      print STDOUT "output = $output_txt_file\nprev = $prev_out_file\n";
      print STDOUT "output = $output_html_file\nprev = $next_out_file\n";
   }
exit 2;
   open(OUTPUT, ">$output_html_file");
   print OUTPUT <<"EOF";
<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.0 Final//EN">
<HTML>
<HEAD>
<TITLE>Hourly tcpdump for $SITE on $dir at $hour.</TITLE>
</HEAD>
<BODY BGCOLOR='ffdead'> 
EOF
   close(OUTPUT);
   if (not -e $output_txt_file) {
      open(OUTPUT, ">>$output_html_file") or die "Can't open $output_html_file";
      print OUTPUT "<H2>Sorry, no data available.</H2>";
   } else {
      print STDOUT "Copying $output_txt_file to $output_html_file.\n";
      open(OUTPUT, ">>$output_html_file") or die "Can't open $output_html_file";
      print OUTPUT "<PRE>\n";
      open(TEXTFILE, "<$output_txt_file") or die "Can't open $output_txt_file";
      while (<TEXTFILE>) {
         print OUTPUT $_;
      }
      close(TEXTFILE);
      print OUTPUT "</PRE>\n";
   }
   print OUTPUT <<"EOF";
<HR>
<TABLE CELLSPACING="0" CELLPADDING="0">
<TR>
<TD ALIGN=CENTER VALIGN=MIDDLE><A HREF="$prev_out_file"><IMG SRC="/images/navbars/2/1.gif" WIDTH="90" HEIGHT="20" BORDER="0" HSPACE="0" VSPACE="0"></A><IMG SRC="/images/navbars/2/2.gif" WIDTH="110" HEIGHT="20" HSPACE="0" VSPACE="0"><A HREF="$URL_OUTPUT_DIR/$dir/index.html"><IMG SRC="/images/navbars/2/3.gif" WIDTH="50" HEIGHT="20" BORDER="0" HSPACE="0" VSPACE="0"></A><IMG SRC="/images/navbars/2/2.gif" WIDTH="110" HEIGHT="20" HSPACE="0" VSPACE="0"><A HREF="$next_out_file"><IMG SRC="/images/navbars/2/5.gif" WIDTH="90" HEIGHT="20" BORDER="0" HSPACE="0" VSPACE="0"></A></TD></TR>
</TABLE>

</BODY>
</HTML>
EOF
   close(OUTPUT);
#
}
print STDOUT "Convert completed.\n";
