#!/usr/bin/perl
#
# $Id: translate.pl,v 1.5 1998/06/22 16:44:23 wralph Exp $
#
# Read a tcpdump file and translate it so the SHADOW analysis engines can
# read it.
#
# Written by Bill Ralph - 3/19/98
#
# Set up some variables.
#
use Getopt::Long;
use Shell qw(gunzip tcpdump);
use POSIX qw(strftime);
#
$ENV{PATH} = "/bin:/usr/bin:/usr/sbin:/usr/local/bin:/usr/local/logger";
$SITE="Site1";
$LEVEL2_HOST="Secondary";

#
sub usage {
        print "Usage: translate.pl -debug -d SNIFDATE -l SITE.\n";
        exit 2;
}
#
#       Parse the parameters.
#
#
&GetOptions("debug", \$debug, "d=s", \$snifdate, "l:s", \$SITE);
##
#
#  Rid ourselves of standard output and error to prevent tons of mail messages
#  from cron.
#
if ( $debug )
{
   open(STDOUT, ">>/tmp/translate.log");
   select STDOUT; $| = 1;
} else {
   open (STDOUT, ">>/dev/null");
   select STDOUT; $| = 1;
}
open(STDERR, ">&STDOUT");
select STDERR; $| = 1;              # make unbuffered
#
# Writer a marker to the log file.
#
$marker=strftime("%c", localtime(time));
chomp $marker;
print STDOUT $marker;
foreach $param ($0, @ARGV) {
   printf " %s", $param;
}
print STDOUT "\n";
#
#
# Using the calling date parameter, reset the $subdir variable.
#
$date_len= length($snifdate);
if ($date_len == 8) {
   $sn1 = substr($snifdate,0,-2);
   $hour = substr($snifdate,6,2);
} else {
   $sn1 = $snifdate;
   $hour = "00";
}
$year=substr($sn1,0,2);
$mon=substr($sn1,2,2) - 1;
$mday=substr($sn1,4,2);
$subdir=strftime("%h%d", 0, 0, 0, $mday, $mon, $year);
$outdate=strftime("%x", 0, 0, 0, $mday, $mon, $year);
print STDOUT "subdir = $subdir, outdate = $outdate\n";
print STDOUT "mday = $mday, mon = $mon, year = $year\n";

#
#  Define a hash variable to hold the actual tcpdump filters for each
#  of the protocols we want translated.
#
%filters = (
   "tcp" => '"(tcp[13] & 2 != 0) and (tcp[13] & 0x10 = 0)"',
   "udp" => '"udp and not port 27500"',
   "icmp"=> '"icmp"',
);

if ($date_len == 8) {
%files = (
   "tcp" => "/LOG/".$SITE."/".$subdir."/tcp.".$snifdate.".gz",
   "udp" => "/LOG/".$SITE."/".$subdir."/tcp.".$snifdate.".gz",
   "icmp"=> "/LOG/".$SITE."/".$subdir."/tcp.".$snifdate.".gz",
);
} else {
%files = (
   "tcp" => "/LOG/".$SITE."/".$subdir . "/day_tcp.gz",
   "udp" => "/LOG/".$SITE."/".$subdir . "/day_udp.gz",
   "icmp"=> "/LOG/".$SITE."/".$subdir . "/day_icmp.gz",
);
}
#  Loop through each of the protocols, read the zipped raw data file and
#  write out the required fields to the new data file.
#
foreach $protocol (keys %filters) {
   print STDOUT "Protocol = $protocol\n";
   $newdest_file= "$SITE/$protocol.$snifdate";
   print STDOUT "Dest.file = $newdest_file\n";
   $ship_cmd="ssh $LEVEL2_HOST " . '"'."cat > $newdest_file".'"';
   print STDOUT "ship_cmd = $ship_cmd\n";
   open(NEWDATA, "|$ship_cmd") or die("Cant open new datafile $!\n");
   $unix_cmd="gunzip -c $files{$protocol} | tcpdump -n -r - $filters{$protocol}";
   print STDOUT "unix_cmd = $unix_cmd\n";
   open(LOGDATA, "$unix_cmd|") || die "Can't open data file: $!\n" ;
#  $oldline="";
   while (<LOGDATA>){
#
# Remove those lines TCPDUMP reports as "truncated data."
#
      if (/truncat/) { next; }
      ($crap, $crap1, $junk3, $crap2) = split(/\s+/,$_);
      chop($crap2);
#
# If the time field is null, skip to next record.
#
      ($time, $milli_time) = split(/\./,$crap);
      if (not $time) { next; }
      ($part1, $part2, $part3, $part4, $src_port) = split(/\./, $crap1);
#
#  If it's not icmp and there is no source port, skip to next record.
#
      if (($protocol ne "icmp") && not $src_port) { next; }
      $src="$part1.$part2.$part3.$part4";
      ($part1, $part2, $part3, $part4, $dst_port) = split(/\./, $crap2);
#
#  If it's not icmp and there is no destination port, skip to next record.
#
      if (($protocol ne "icmp") && not $dst_port) { next; }
      $dest="$part1.$part2.$part3.$part4";
#
#  If we're dealing with NFS, change the "xid" from TCPDUMP to zero for
#  compatability with second level analysis.
#
      if ($protocol eq "udp") {
         if ($src_port eq "2049") { $dst_port = 0;}
         if ($dst_port eq "2049") { $src_port = 0;}
      }
#
#  Compare this line to its predecessor. If they're the same, don't print it.
#
      $newline="$outdate $time,$src,$src_port,$dest,$dst_port,$protocol\n";
#     if ($newline ne $oldline) {
         print NEWDATA $newline;
#     }
#     $oldline=$newline;
   }
   close(LOGDATA);
   close(NEWDATA);
}
